@@ -21,7 +21,6 @@ import (
 type Client struct {
 	db     *sqlx.DB
 	driver string
-	limit  int
 }
 
 // New return an instance of the client.
@@ -39,7 +38,6 @@ func New(opts command.Options) (*Client, error) {
 	c := Client{
 		db:     db,
 		driver: opts.Driver,
-		limit:  opts.Limit,
 	}
 
 	return &c, nil
@@ -140,9 +138,9 @@ func (c *Client) TableContent(tableName string) ([][]string, []string, error) {
 	var query string
 
 	if c.driver == "postgres" || c.driver == "postgresql" {
-		query = fmt.Sprintf("SELECT * FROM public.%s LIMIT %d;", tableName, c.limit)
+		query = fmt.Sprintf("SELECT * FROM public.%s LIMIT 100;", tableName)
 	} else {
-		query = fmt.Sprintf("SELECT * FROM %s LIMIT %d;", tableName, c.limit)
+		query = fmt.Sprintf("SELECT * FROM %s LIMIT 100;", tableName)
 	}
 
 	return c.Query(query)
